@@ -92,6 +92,12 @@ data = {
                         "default": False,
                         "help": "generate the changelog for the newest version",
                     },
+                    {
+                        "name": ["--no-verify"],
+                        "action": "store_true",
+                        "default": False,
+                        "help": "this option bypasses the pre-commit and commit-msg hooks",
+                    },
                     {
                         "name": "--yes",
                         "action": "store_true",
